# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Public Classes

* [`perfsonar`](#perfsonar): Manage perfSONAR

#### Private Classes

* `perfsonar::config`: Manage perfSONAR configs
* `perfsonar::firewall`: Manage perfSONAR firewall rules
* `perfsonar::install`: Manage perfsonar packages
* `perfsonar::lsregistrationdaemon`: Manage perfsonar-lsregistrationdaemon service
* `perfsonar::pscheduler::agent`: Manage pschedular-agent service
* `perfsonar::repo`: Manage perfsonar repo

## Classes

### <a name="perfsonar"></a>`perfsonar`

Manage perfSONAR

#### Examples

##### 

```puppet
include perfsonar
```

#### Parameters

The following parameters are available in the `perfsonar` class:

* [`manage_repo`](#manage_repo)
* [`manage_epel`](#manage_epel)
* [`bundle`](#bundle)
* [`optional_packages`](#optional_packages)
* [`manage_firewall`](#manage_firewall)
* [`with_ipv6`](#with_ipv6)
* [`web_admin_username`](#web_admin_username)
* [`web_admin_password`](#web_admin_password)
* [`remove_root_prompt`](#remove_root_prompt)
* [`apache_group`](#apache_group)
* [`manage_apache`](#manage_apache)
* [`ssl_cert`](#ssl_cert)
* [`ssl_key`](#ssl_key)
* [`ssl_chain_file`](#ssl_chain_file)
* [`apache_ssl_conf`](#apache_ssl_conf)
* [`apache_service`](#apache_service)
* [`primary_interface`](#primary_interface)
* [`manage_pscheduler_agent`](#manage_pscheduler_agent)
* [`pscheduler_agent_config`](#pscheduler_agent_config)
* [`manage_lsregistrationdaemon`](#manage_lsregistrationdaemon)
* [`lsregistrationdaemon_ensure`](#lsregistrationdaemon_ensure)
* [`lsregistrationdaemon_enable`](#lsregistrationdaemon_enable)

##### <a name="manage_repo"></a>`manage_repo`

Data type: `Boolean`

Boolean that determines if perfSONAR repos will be managed.

Default value: ``true``

##### <a name="manage_epel"></a>`manage_epel`

Data type: `Boolean`

Boolean that determines if EPEL repo is managed.

Default value: ``true``

##### <a name="bundle"></a>`bundle`

Data type: `Enum['perfsonar-tools','perfsonar-testpoint','perfsonar-core','perfsonar-centralmanagement','perfsonar-toolkit']`

The perfSONAR bundle package to install

Default value: `'perfsonar-toolkit'`

##### <a name="optional_packages"></a>`optional_packages`

Data type: `Array`

Array of optional packages to install

Default value: `[]`

##### <a name="manage_firewall"></a>`manage_firewall`

Data type: `Boolean`

Boolean that determines if firewall rules are managed.

Default value: ``true``

##### <a name="with_ipv6"></a>`with_ipv6`

Data type: `Boolean`

Boolean that determines if IPv6 support should be enabled

Default value: ``false``

##### <a name="web_admin_username"></a>`web_admin_username`

Data type: `String`

User name used to log into perfSONAR web interface

Default value: `'admin'`

##### <a name="web_admin_password"></a>`web_admin_password`

Data type: `Optional[String]`

Password for perfSONAR web login

Default value: ``undef``

##### <a name="remove_root_prompt"></a>`remove_root_prompt`

Data type: `Boolean`

Boolean that determines if file should be removed that
provides a prompt for setup when root logs in.

Default value: ``false``

##### <a name="apache_group"></a>`apache_group`

Data type: `String`

Group used by Apache

Default value: `'apache'`

##### <a name="manage_apache"></a>`manage_apache`

Data type: `Boolean`

Boolean that sets if Apache should be managed

Default value: ``false``

##### <a name="ssl_cert"></a>`ssl_cert`

Data type: `Stdlib::Absolutepath`

The path to Apache SSL certificate

Default value: `'/etc/pki/tls/certs/localhost.crt'`

##### <a name="ssl_key"></a>`ssl_key`

Data type: `Stdlib::Absolutepath`

The path to Apache SSL private key

Default value: `'/etc/pki/tls/private/localhost.key'`

##### <a name="ssl_chain_file"></a>`ssl_chain_file`

Data type: `Optional[Stdlib::Absolutepath]`

The path to Apache SSL chain file

Default value: ``undef``

##### <a name="apache_ssl_conf"></a>`apache_ssl_conf`

Data type: `Stdlib::Absolutepath`

The path to Apache SSL configuration file

Default value: `'/etc/httpd/conf.d/ssl.conf'`

##### <a name="apache_service"></a>`apache_service`

Data type: `String`

The Apache service name

Default value: `'httpd'`

##### <a name="primary_interface"></a>`primary_interface`

Data type: `Optional[String]`

The primary interface of host

Default value: `('networking','primary')`

##### <a name="manage_pscheduler_agent"></a>`manage_pscheduler_agent`

Data type: `Boolean`

Weather or not the pscheduler-agent daemon should be managed

Default value: ``false``

##### <a name="pscheduler_agent_config"></a>`pscheduler_agent_config`

Data type: `Optional[Hash]`

Configuration to convert to json and write to pscheduler-agent.json

Default value: ``undef``

##### <a name="manage_lsregistrationdaemon"></a>`manage_lsregistrationdaemon`

Data type: `Boolean`

Weather or not the perfsonar-lsregistrationdaemon daemon should be managed

Default value: ``false``

##### <a name="lsregistrationdaemon_ensure"></a>`lsregistrationdaemon_ensure`

Data type: `Stdlib::Ensure::Service`

perfsonar-lsregistrationdaemon service ensure

Default value: `'running'`

##### <a name="lsregistrationdaemon_enable"></a>`lsregistrationdaemon_enable`

Data type: `Boolean`

perfsonar-lsregistrationdaemon service enable

Default value: ``true``

